@@ -1,6 +1,6 @@
 #' BP_pred_MGWRSAR
 #' to be documented
-#' @usage BP_pred_MGWRSAR(YS,X,W,e,beta_hat,lambda_hat,S,O,coord,type='BPN',k=16,Wk=NULL)
+#' @usage BP_pred_MGWRSAR(YS,X,W,e,beta_hat,lambda_hat,S,O,coords,type='BPN',k=16,Wk=NULL)
 #' @param YS to be documented
 #' @param X to be documented
 #' @param W to be documented
@@ -9,7 +9,7 @@
 #' @param lambda_hat to be documented
 #' @param S to be documented
 #' @param O to be documented
-#' @param coord to be documented
+#' @param coords to be documented
 #' @param type to be documented
 #' @param k to be documented
 #' @param Wk to be documented
@@ -17,14 +17,14 @@
 #'
 #' @return to be documented
 BP_pred_MGWRSAR <-
-function(YS,X,W,e,beta_hat,lambda_hat,S,O,coord,type='BPN',k=16,Wk=NULL){
+function(YS,X,W,e,beta_hat,lambda_hat,S,O,coords,type='BPN',k=16,Wk=NULL){
 ###  YS = c(Y_insample)
 ###  X = rbind(X_insample,X_outsample)
 ###  e=residuals_insample
 ###  beta_hat,lambda_hat = coef_insample
 ###  S,O index of insample and outsample
 ## computation of Beta_hat on the whole sample
-if(is.null(Wk)) Wk=(Beta_extropolation(coord=coord,k=k,O,type='S+OxS+O'))[-S,-O]
+if(is.null(Wk)) Wk=(Beta_extropolation(coords=coords,k=k,O,type='S+OxS+O'))[-S,-O]
 beta_hat=rbind(beta_hat,as.matrix(Wk %*% beta_hat))
 if(length(lambda_hat)>1) lambda_hat=as.numeric(c(lambda_hat,as.numeric(Wk %*% lambda_hat)))
 ###
