@@ -5,7 +5,7 @@
 #' If Type!='GD' then S should have additional columns and several
 #' kernels and bandwidths should be be specified by the user.
 #' @usage kernel_matW(H,kernels,coord_i,coord_j=NULL,NN,ncolX=1,
-#' Type='GD',adaptive=F,diagnull=TRUE,rowNorm=TRUE,noisland=FALSE)
+#' Type='GD',adaptive=FALSE,diagnull=TRUE,rowNorm=TRUE,noisland=FALSE)
 #' @param H  A vector of bandwidths
 #' @param kernels  A vector of kernel types
 #' @param coord_i  A matrix with  variables used in kernel (reference)
@@ -25,11 +25,11 @@
 #'  library(mgwrsar)
 #'  ## loading data example
 #'  data(mydata)
-#'  coord=as.matrix(mydata[,c("x_lat","y_lon")])
+#'  coords=as.matrix(mydata[,c("x","y")])
 #'  ## Creating a spatial weight matrix (sparce dgCMatrix) of 4 nearest neighbors with 0 in diagonal
-#'  W=kernel_matW(H=4,kernels='rectangle',coord_i=coord,NN=4,adaptive=TRUE,diagnull=TRUE,rowNorm=TRUE)
+#'  W=kernel_matW(H=4,kernels='rectangle',coord_i=coords,NN=4,adaptive=TRUE,diagnull=TRUE,rowNorm=TRUE)
 #' }
-kernel_matW<-function(H,kernels,coord_i,coord_j=NULL,NN,ncolX=1,Type='GD',adaptive=F,diagnull=TRUE,rowNorm=TRUE,noisland=FALSE){
+kernel_matW<-function(H,kernels,coord_i,coord_j=NULL,NN,ncolX=1,Type='GD',adaptive=FALSE,diagnull=TRUE,rowNorm=TRUE,noisland=FALSE){
   m<-n<-nrow(coord_i)
   if(is.null(coord_j)){
     while(sum(duplicated(coord_i))>0) {
