@@ -1,11 +1,11 @@
 #' mgwrsar Model Predictions
 #' predict_mgwrsar is a function for computing predictions of a mgwrsar models. It uses Best Linear Unbiased Predictor for mgwrsar models with spatial autocorrelation.
-#' @usage predict_mgwrsar(model, newdata, newdata_coord, W = NULL, type = "BPN",
+#' @usage predict_mgwrsar(model, newdata, newdata_coords, W = NULL, type = "BPN",
 #' h_w = 100,kernel_w = "rectangle",maxobs=4000,beta_proj=FALSE,
 #' method_pred='TP', k_extra = 8)
 #' @param model a model of mgwrsar class.
 #' @param newdata a matrix or data.frame of new data.
-#' @param newdata_coord  a matrix of new coordinates, and eventually other variables if a General Kernel Product is used.
+#' @param newdata_coords  a matrix of new coordinates, and eventually other variables if a General Kernel Product is used.
 #' @param W the spatial weight matrix for models with  spatial autocorrelation.
 #' @param type Type for BLUP estimator, default "BPN". If NULL use predictions without spatial bias correction.
 #' @param  h_w A bandwidth value for the spatial weight matrix
@@ -29,27 +29,31 @@
 #' \donttest{
 #' library(mgwrsar)
 #'  data(mydata)
-#'  coord=as.matrix(mydata[,c("x_lat","y_lon")])
+#'  coords=as.matrix(mydata[,c("x","y")])
 #' length_out=800
 #' index_in=sample(1:1000,length_out)
 #' index_out=(1:1000)[-index_in]
 #'
 #' model_GWR_insample<-MGWRSAR(formula = 'Y_gwr~X1+X2+X3', data = mydata[index_in,],
-#' coord=coord[index_in,],fixed_vars=NULL,kernels=c ('gauss'),H=8, Model = 'GWR',
+#' coords=coords[index_in,],fixed_vars=NULL,kernels=c ('gauss'),H=8, Model = 'GWR',
 #' control=list(adaptive=TRUE))
 #' summary_mgwrsar(model_GWR_insample)
 #'
 #' newdata=mydata[index_out,]
-#' newdata_coord=coord[index_out,]
+#' newdata_coords=coords[index_out,]
 #' newdata$Y_mgwrsar_1_0_kv=0
 #'
 #' Y_pred=predict_mgwrsar(model_GWR_insample, newdata=newdata,
-#' newdata_coord=newdata_coord)
+#' newdata_coords=newdata_coords)
 #' head(Y_pred)
 #' head(mydata$Y_gwr[index_out])
 #' sqrt(mean((mydata$Y_gwr[index_out]-Y_pred)^2)) # RMSE
 #' }
-predict_mgwrsar  <- function(model, newdata, newdata_coord, W = NULL, type = "BPN", h_w = 100,kernel_w = "rectangle",maxobs=4000,beta_proj=FALSE,method_pred='TP', k_extra = 8) {
+predict_mgwrsar  <- function(model, newdata, newdata_coords, W = NULL, type = "BPN", h_w = 100,kernel_w = "rectangle",maxobs=4000,beta_proj=FALSE,method_pred='TP', k_extra = 8) {
+  if(method_pred !='sheppard' & model$Model %in% c('multiscale_gwr','tds_mgwr')) {
+    cat("Warning: only sheppard method for method_pred can be used with multiscale_gwr and tds_mgwr \n automatic switch to method_pred='sheppard'")
+    method_pred='sheppard'
+  }
   if(is.null(model$TP) | length(model$TP)==nrow(model$X)) noTP=TRUE else noTP=FALSE
 if(!is(model,'mgwrsar')) stop('A mgwrsar class object is required')
 if(model$Model %in% c('MGWR','MGWRSAR_1_0_kv','MGWRSAR_1_kc_0','MGWRSAR_1_kc_kv','MGWRSAR_0_kc_kv','MGWRSAR_0_0_kv') & method_pred=='TP') {
@@ -60,7 +64,7 @@ if(length(model$TP)!=length(model$Y) & method_pred=='TP') {
     cat("Warnings: if estimated model used target points, method_pred ='TP' may be innapropriate if out-sample size is large: method_pred='tWtp_model' should be faster")
 }
 
-if(is.null(newdata) | is.null(newdata_coord)) stop('provide the newdata and newdata_coord objects')
+if(is.null(newdata) | is.null(newdata_coords)) stop('provide the newdata and newdata_coords objects')
 #######
   newdata<-data.frame(newdata)
   myYname=terms(as.formula(model$formula))[[2]]
@@ -72,12 +76,12 @@ if(is.null(newdata) | is.null(newdata_coord)) stop('provide the newdata and newd
   insample_size=length(model$Y) ## insample
   outsample_size=nrow(newdata)  ###outsample
 
-  if(ncol(newdata_coord)>2) {
-    colnames(model$S)<- colnames(newdata_coord)
-    coords=rbind(model$S,newdata_coord)
+  if(ncol(newdata_coords)>2) {
+    colnames(model$S)<- colnames(newdata_coords)
+    coords=rbind(model$S,newdata_coords)
     } else {
-      colnames(model$coord)<- colnames(newdata_coord)
-      coords=rbind(model$coord,newdata_coord)
+      colnames(model$coords)<- colnames(newdata_coords)
+      coords=rbind(model$coords,newdata_coords)
     }
   m=insample_size
   n=outsample_size+insample_size
@@ -94,19 +98,19 @@ if(is.null(newdata) | is.null(newdata_coord)) stop('provide the newdata and newd
   #if(model$Model =='GWR') {
     model$mycall$control[['W']]<-quote(model$W)
     con=eval(model$mycall$control)
-    #con=c(con, list(S_out=newdata_coord,new_data=newdata,new_W=W))
+    #con=c(con, list(S_out=newdata_coords,new_data=newdata,new_W=W))
     full_data=rbind(newdata,model$data)
-    full_coord=rbind(newdata_coord,model$coord)
+    full_coords=rbind(newdata_coords,model$coords)
     TP=1:length(O)
     con=c(con, list(TP=TP,isgcv=TRUE,S_out=TRUE))
-    pred_TP<-MGWRSAR(formula = model$formula, data = full_data,coord=full_coord, fixed_vars=model$fixed_vars,kernels=model$kernels,H=model$H, Model=model$Model ,control=con)
+    pred_TP<-MGWRSAR(formula = model$formula, data = full_data,coords=full_coords, fixed_vars=model$fixed_vars,kernels=model$kernels,H=model$H, Model=model$Model ,control=con)
     Y_predicted=pred_TP$fit[TP]
     # } else if(model$Model =='MGWRSAR_1_0_kv'){
     # lambda_in=model$Betav[,ncol(model$Betav)]
     # beta_in=model$Betav[,-ncol(model$Betav)]
     # model$mycall$control[['W']]<-quote(model$W)
-    # con=call_modify(model$mycall$control, S_out=quote(newdata_coord),new_data=quote(newdata),new_W=quote(W))
-    # pred_TP<-MGWRSAR(formula = model$formula, data = model$data,coord=model$coord, fixed_vars=model$fixed_vars,kernels=model$kernels,H=model$H, Model=model$Model ,control=eval(con))
+    # con=call_modify(model$mycall$control, S_out=quote(newdata_coords),new_data=quote(newdata),new_W=quote(W))
+    # pred_TP<-MGWRSAR(formula = model$formula, data = model$data,coords=model$coords, fixed_vars=model$fixed_vars,kernels=model$kernels,H=model$H, Model=model$Model ,control=eval(con))
     #
     # beta_out=pred_TP$pred$beta_pred
     # lambda_out=pred_TP$pred$lambda_pred
@@ -125,7 +129,7 @@ colnames(newdata)[1]='Intercept'
 
 if(!(model$Model %in% c('OLS','SAR'))){
   ###
-  if(model$Model %in% c('GWR','multiscale_GWR')) {
+  if(model$Model %in% c('GWR','multiscale_gwr','tds_mgwr')) {
     beta_in=model$Betav
   } else if(model$Model=='MGWR') {
     beta_in=cbind(model$Betav,matrix(model$Betac,nrow=m,ncol=length(model$Betac),byrow=TRUE))
@@ -150,21 +154,21 @@ if(!(model$Model %in% c('OLS','SAR'))){
   }
   #beta_in<-beta_in[model$TP,colnames(model$X)]
   namesX=colnames(model$X)
-  if(!(model$Model %in% c('GWR','MGWR','multiscale_GWR'))){
+  if(!(model$Model %in% c('GWR','MGWR','multiscale_gwr','tds_mgwr'))){
     lambda_in<-lambda_in[model$TP]
     il=which(namesX=='lambda')
     if(length(il)>0) namesX<-namesX[-il]
     }
   newdata=newdata[,namesX]
-  #if(model$Model =='multiscale_GWR') newdata=apply(newdata,2,function(x) scale(x,scale=F))
+  #if(model$Model =='multiscale_GWR') newdata=apply(newdata,2,function(x) scale(x,scale=FALSE))
 
   if(method_pred=='tWtp_model'){
     W_extra=kernel_matW(H=model$H,kernels=model$kernels,coord_i=coords[S,],coord_j=coords,NN=model$NN,Type=model$Type,adaptive=model$adaptive,diagnull=FALSE,rowNorm=TRUE)[,-(1:nrow(model$Betav))]
     W_extra<- normW(Matrix::t(W_extra))
   } else if(method_pred=='model'){
-    W_extra=kernel_matW(H=model$H,kernels=model$kernels,coord_i=rbind(model$coord,newdata_coord),coord_j=model$coord,NN=model$NN,Type=model$Type,adaptive=model$adaptive,diagnull=FALSE,rowNorm=TRUE)[-(1:nrow(model$Betav)),]
+    W_extra=kernel_matW(H=model$H,kernels=model$kernels,coord_i=rbind(model$coords,newdata_coords),coord_j=model$coords,NN=model$NN,Type=model$Type,adaptive=model$adaptive,diagnull=FALSE,rowNorm=TRUE)[-(1:nrow(model$Betav)),]
   } else {
-    W_extra=kernel_matW(H=k_extra,kernels='sheppard',coord_i=rbind(model$coord,newdata_coord),coord_j=model$coord,NN=k_extra+1,Type=model$Type,adaptive=FALSE,diagnull=FALSE,rowNorm=TRUE)[-(1:nrow(model$Betav)),]
+    W_extra=kernel_matW(H=k_extra,kernels='sheppard',coord_i=rbind(model$coords,newdata_coords),coord_j=model$coords,NN=k_extra+1,Type=model$Type,adaptive=FALSE,diagnull=FALSE,rowNorm=TRUE)[-(1:nrow(model$Betav)),]
 
   }
 } else if(model$Model=='SAR') {
@@ -180,7 +184,7 @@ h_w=model$h_w
 kernel_w=model$kernel_w
 }
 
-if(is.null(W) & !(model$Model %in% c('OLS','GWR','MGWR','multiscale_GWR'))) {
+if(is.null(W) & !(model$Model %in% c('OLS','GWR','MGWR','multiscale_gwr','tds_mgwr'))) {
   W=kernel_matW(H=h_w,kernels=kernel_w,coord_i=coords,diagnull=TRUE,NN=h_w,adaptive=TRUE,rowNorm=TRUE)
 }
 
@@ -190,7 +194,7 @@ if(model$Model=='SAR') {
   } else if(model$Model %in% c('MGWRSAR_1_0_kv','MGWRSAR_0_0_kv','MGWRSAR_1_kc_kv','MGWRSAR_0_kc_kv','MGWRSAR_1_kc_0'))  {
     Y_predicted=BP_pred_SAR(YS,X=as.matrix(rbind(model$X,newdata)),W,e,beta_hat=rbind(beta_in,as.matrix(W_extra %*%beta_in)),lambda_hat=c(lambda_in,as.numeric(W_extra %*%lambda_in)),S,O,type,k_extra=k_extra,kernel_extra=kernel_extra,model=model$Model, W_extra = W_extra,coords=coords,maxobs=maxobs)
 
-  } else if (model$Model %in% c('GWR','GWRtp','GWRboost','MGWR','multiscale_GWR')) {
+  } else if (model$Model %in% c('GWR','GWRtp','GWRboost','MGWR','multiscale_gwr','tds_mgwr')) {
     X=as.matrix(newdata)
     Beta_proj_out=as.matrix(W_extra %*% beta_in)
     #else Beta_proj_out=as.matrix(W_extra %*% beta_in[model$TP,])
