@@ -10,8 +10,7 @@ function (object, ...)
     d <- dim(object)
     T <- as(object, "TsparseMatrix")
     r <- data.frame(i = T@i + 1L, j = T@j + 1L, x = T@x)
-    attr(r, "header") <- sprintf("%d x %d sparse Matrix of class \"%s\", with %d entries",
-        d[1], d[2], class(object), nnzero(object))
+    attr(r, "header") <- paste0(d[1]," x ",d[2], "sparse Matrix of class '",class(object),"' with",nnzero(object))
     class(r) <- c("sparseSummary", class(r))
     r
 }
